cd "XXXXXX"
insheet using "mturk_batch_results.csv", clear
rename answeranswer respondentid
gsort respondentid submittime
drop if respondentid==respondentid[_n-1]
gen periodpos=strpos(respondentid,".")
keep respondentid workerid
save "mturk_match.dta", replace

insheet using final_data.csv, clear
sort respondentid
merge 1:1 respondentid using mturk_match.dta
*drop cases where response not merged to MTurk batch data
keep if _merge==3
drop _merge
drop if country!="United States" & country!="" 

   foreach v of varlist _all {
      capture rename `v' `=lower("`v'")'
   }
   
***DEMOGRAPHICS
*Party ID
rename generallyspeakingdoyouusuallythi pid_stem
rename wouldyoucallyourselfastrongdemoc pid_dstr
rename wouldyoucallyourselfastrongrepub pid_rstr
rename doyouthinkofyourselfasclosertoth pid_lean
egen pid=rmean(pid_dstr pid_rstr pid_lean)
label var pid "Party ID (-3=str. D; 3=str. R)"
rename whatistheyearofyourbirth yob
gen age=2015-yob
qui sum age
replace age=r(mean) if age==.
label var age "Age (in years)"

rename whatisthehighestlevelofeducation educ
label var educ "Education (1=No HS; 6=post-grad)"
rename whatwasyourtotalfamilyincomein20 income
label var income "Income (1=<$10k; 14=$150k+; 15=refused)"
gen incomemis=(income==15)
replace incomemis=1 if income==.
replace income=15 if income==.
label var incomemis "Income Refused/Missing (1=yes)"

foreach i in white black hispanic asian nativeamerican mixed other{
rename `i'whatracialorethnic r_`i'
 replace r_`i'=0 if r_`i'==.
 replace r_`i'=1 if r_`i'!=0
 label var r_`i' "`i' = 1"
}
replace r_other=r_asian+r_nativeam+r_mixed+r_other
replace r_other=1 if r_other>1
replace r_white=0 if (r_black==1)| (r_hispanic==1)|(r_other==1)
replace r_black=0 if (r_hispanic==1)|(r_other==1)
replace r_hispanic=0 if (r_other==1)
replace r_other=1 if (r_white!=1)&(r_black!=1)&(r_hispanic!=1)

label var r_other "Other race / Skipped (1=yes)"
label var r_white "White (1=yes)"
label var r_black "Black (1=yes)"
label var r_hispanic "Hispanic (1=yes)"
drop r_asian r_nativeam r_mixed 

rename whatisyourgender female
label var female "Female (1=yes)"

recode howinterestedareyouinpoliticsand (1=1) (2=2) (3=3) (*=.), gen(polinterest)
label var polinterest "Interest in politics (1=not at all; 3=very interested)"

gen ideology=(wehearalotoftalkthesedaysaboutli-4)
label var ideology "Ideology (-3=v. liberal; 3=v. conservative)"

***EXPERIMENTAL TREATMENTS
tab fullname, gen(name_)
drop name_1
rename name_2 trt_name_arab
rename name_3 trt_name_anglo
label var trt_name_arab "Treatment: Arabic Name"
label var trt_name_anglo "Treatment: Anglo Name"

tab violence, gen(vio)
rename vio1 trt_violence
replace trt_violence=0 if trt_violence==.
label var trt_violence "Treatment: Explicit Call to Violence"

tab description_1, gen(desc_)
drop desc_3
rename desc_1 trt_desc_terror
rename desc_2 trt_desc_violence
label var trt_desc_terror "Treatment: Advocating Terrorism"
label var trt_desc_violence "Treatment: Advocating Violence"


***OUTCOMES
rename doyousupportoropposethefbisdecis support_arrest
label var support_arrest "Support FBI Decision to Arrest (1-7)"
rename whichofthefollowingcomesclosestt how_long_hold
label var how_long_hold "How Long Hold Suspect (1-8)"
recode shouldthegovernmentprovidethespe (1=1) (2=0), gen(provide_lawyer)
label var provide_lawyer "Gov. Provide Lawyer (1=yes)"
recode ifthespeakeryoureadaboutistriedd  (1=3) (2=2) (3=1) (*=.), gen(public_trial)
label var public_trial "Trial should be public (1-3)"
gen how_long_hold0_1=(how_long_hold-8)/-7
gen public_trial0_1=(public_trial-1)/2

rename howmuchwouldyousayyoupersonallya agree_w_speech
label var agree_w_speech "Agreement with Speech (1-7)"
recode ingeneraldoyouthinkspeechesliket (1=7) (2=6) (3=5) (4=4) (5=3) (6=2) (7=1) (*=.), gen(encourage_speech)
label var encourage_speech "Encourage Speech Like This (1-7)"


*speaker motives
rename toencourageterrorismbasedonwhaty mot_terrorism
rename toencourageviolencebasedonwhatyo mot_violence
rename toencouragevandalismbasedonwhaty mot_vandalism
rename toencouragecriminalactivitybased mot_criminal
rename topersuadethepublictoopposeusfor mot_pers_public
rename topersuadepresidentobamatochange mot_obama
rename topersuademembersofcongresstocha mot_congress
rename toencourageforeignerstofightusfo mot_foreign
label var mot_terrorism "Motivation: Encourage terrorism (0-100)"
label var mot_violence "Motivation: Encourage violence (0-100)"
label var mot_vandalism "Motivation: Encourage vandalism (0-100)"
label var mot_criminal "Motivation: Encourage criminal activity (0-100)"
label var mot_pers_public "Motivation: Persuade public (0-100)"
label var mot_obama "Motivation: Persuade Obama (0-100)"
label var mot_congress "Motivation: Persuade Congress (0-100)"
label var mot_foreign "Motivation: Encourage foreigners to fight (0-100)"

rename wouldyousaythatthisspeakerwasadv advocating_terrorism
rename v56 advocating_violence
label var advocating_terrorism "Speaker was Advocating Terrorism (0-100)"
label var advocating_violence "Speaker was Advocating Violence (0-100)"
egen advocacy=rmean(advocating_violence advocating_terrorism)
label var advocacy "Speaker was Advocating Violence/Terrorism (0-100)"

rename howlikelydoyouthinkitisthataspee imminent_violence
rename v58 eventual_violence
label var imminent_violence "Likely to lead to immediate violence (0-100)"
label var eventual_violence "Likely to lead to eventual violence (0-100)"
egen lead_to_violence=rmean(imminent_violence eventual_violence)
label var lead_to_violence "Likely to Lead to Violence Index (0-100)"

rename howlikelydoyouthinkitisthatperso other_plots
label var other_plots "Likely involved in planning terrorist attacks (0-100)"
recode supposethespeakeryoureadaboutwan shouldthespeakeryoureadaboutbeal (1=1) (2=0), gen(gss_speech gss_teach)
recode supposethespeakeryoureadabouthad (1=0) (2=1), gen(gss_book)
label var gss_speech "Allow to give a speech (1=yes)"
label var gss_teach "Allow to teach (1=yes)"
label var gss_book "Keep book in library (1=yes)"

recode basedonwhatyouhavereadorhearddoy basedonwhatyouhavereadorhearddoy doyouthinktheunitedstatesmilitar (1=1) (2=0) (8=.5),gen(fp_isis fp_afghan fp_iraq)
label var fp_isis "Support FP: ISIS (1=yes; DK=.5)"
label var fp_afghan "Support FP: Afghanistan (1=yes; DK=.5)"
label var fp_iraq "Support FP: Iraq (1=yes; DK=.5)"
recode howdoyoufeelaboutthepossibilityo (1=4) (2=3) (3=2) (4=1) (*=.),gen(worried)
label var worried "Worried about attack in US? (1-4)"
alpha fp_isis fp_afghan fp_iraq, gen(fp_index)
label var fp_index "Index of Support for Hawkish FP (0-1)"


rename doyouhappentorecallthenameofthes recall_name
label var recall_name "Name Recall"

rename doyouhappentorecallthereligionof recall_relig
label var recall_relig "Religion Recall"

rename doyouhappentorecallwhetherthespe recall_said_violent
label var recall_said_violent "Recall Statement: Violence"

rename v70 recall_said_care
label var recall_said_care "Recall Statement: US Care"

keep support_arrest encourage_speech public_trial0 public_trial provide_lawyer how_long_hold0 how_long_hold gss_speech gss_teach gss_book advocating_violence advocating_terrorism mot_* imminent_violence eventual_violence agree_w_speech other_plots worried trt_violence trt_name_arab trt_name_anglo trt_desc_terror trt_desc_violence age pid female r_white r_black r_hispanic polinterest educ income incomemis

save "replication_data.dta", replace
